local M = {}

function M:peek() end

function M:seek() end

function M:fetch() return true end

function M:preload() return true end

function M:spot() end

return M
